@@ -31,15 +31,59 @@
 #include <QScrollBar>
 #include <QTextCodec>
 #include <QFile>
+#include <QFileInfo>
 #include <QInputContext>
+#include <QTextDocumentFragment>
 #include "blockdata.h"
 
-LatexEditor::LatexEditor(QWidget *parent,QFont & efont, QColor colMath, QColor colCommand, QColor colKeyword,bool inlinespelling,QString ignoredWords,Hunspell *spellChecker,bool tabspaces,int tabwidth) : QPlainTextEdit(parent),c(0)
+static void convertToPlainText(QString &txt)
 {
+    QChar *uc = txt.data();
+    QChar *e = uc + txt.size();
+
+    for (; uc != e; ++uc) {
+        switch (uc->unicode()) {
+        case 0xfdd0: // QTextBeginningOfFrame
+        case 0xfdd1: // QTextEndOfFrame
+        case QChar::ParagraphSeparator:
+        case QChar::LineSeparator:
+            *uc = QLatin1Char('\n');
+            break;
+        case QChar::Nbsp:
+            *uc = QLatin1Char(' ');
+            break;
+        default:
+            ;
+        }
+    }
+}
+
+LatexEditor::LatexEditor(QWidget *parent,QFont & efont, QList<QColor> edcolors, QList<QColor> hicolors,bool inlinespelling,QString ignoredWords,Hunspell *spellChecker,bool tabspaces,int tabwidth,const QKeySequence viewfocus, QString name) : QPlainTextEdit(parent),c(0)
+{
+fname=name;
+vfocus=viewfocus;
+/***********************/
+inBlockSelectionMode=false;
+blockSelection.tabSize=tabwidth;
+blockSelection.clear();
+setCursorWidth(2);
+/***********************/
+colorBackground=edcolors.at(0);
+colorLine=edcolors.at(1);
+colorHighlight=edcolors.at(2);
+colorCursor=hicolors.at(0);
+
 QPalette p = palette();
-p.setColor(QPalette::Inactive, QPalette::Highlight,p.color(QPalette::Active, QPalette::Highlight));
-p.setColor(QPalette::Inactive, QPalette::HighlightedText,p.color(QPalette::Active, QPalette::HighlightedText));
+p.setColor(QPalette::Active, QPalette::Base, colorBackground);
+p.setColor(QPalette::Inactive, QPalette::Base, colorBackground);
+p.setColor(QPalette::Inactive, QPalette::Window, colorBackground);
+p.setColor(QPalette::Active, QPalette::Window, colorBackground);
+//p.setColor( backgroundRole(), Qt::black );
+// p.setColor(QPalette::Inactive, QPalette::Highlight,p.color(QPalette::Active, QPalette::Highlight));
+// p.setColor(QPalette::Inactive, QPalette::HighlightedText,p.color(QPalette::Active, QPalette::HighlightedText));
 setPalette(p);
+setBackgroundVisible(true);
+
 setFrameStyle(QFrame::NoFrame);
 //setAcceptRichText(false);
 setLineWidth(0);
@@ -75,12 +119,16 @@ if (wordsfile.open(QFile::ReadOnly))
 
 highlighter = new LatexHighlighter(document(),inlinespelling,ignoredWords,spellChecker);
 highlighter->SetEditor(this);
-highlighter->setColors(colMath,colCommand,colKeyword);
+highlighter->setColors(hicolors);
+QFileInfo fi(fname);
+if (!fname.startsWith("untitled") && (fi.suffix()=="asy" || fi.suffix()=="mp")) highlighter->setModeGraphic(true);
+
 
 //c=0;
 //connect(this, SIGNAL(cursorPositionChanged()), viewport(), SLOT(update()));
 connect(this, SIGNAL(cursorPositionChanged()), this, SLOT(matchAll()));
 connect(this, SIGNAL(blockCountChanged(int)), this, SLOT(requestNewNumLines(int)));
+
 //connect(this, SIGNAL(cursorPositionChanged()), this, SLOT(matchLat()));
 //grabShortcut(QKeySequence(Qt::SHIFT + Qt::Key_Tab), Qt::WidgetShortcut);
 //setCenterOnScroll(true);
@@ -96,28 +144,250 @@ LatexEditor::~LatexEditor(){
 //delete pChecker;
 }
 
+void LatexEditor::setColors(QList<QColor> colors)
+{
+colorBackground=colors.at(0);
+colorLine=colors.at(1);
+colorHighlight=colors.at(2);
+QPalette p = palette();
+p.setColor(QPalette::Active, QPalette::Base, colorBackground);
+p.setColor(QPalette::Inactive, QPalette::Base, colorBackground);
+p.setColor(QPalette::Inactive, QPalette::Window, colorBackground);
+p.setColor(QPalette::Active, QPalette::Window, colorBackground);
+//p.setColor( backgroundRole(), Qt::black );
+// p.setColor(QPalette::Inactive, QPalette::Highlight,p.color(QPalette::Active, QPalette::Highlight));
+// p.setColor(QPalette::Inactive, QPalette::HighlightedText,p.color(QPalette::Active, QPalette::HighlightedText));
+setPalette(p);
+setBackgroundVisible(true);
+update();
+}
+
 void LatexEditor::paintEvent(QPaintEvent *event)
 {
-QColor selBlendColor=QColor("#FF0000");
+QPainter painter(viewport());
+QColor selBlendColor=colorHighlight;
 QColor blCol = selBlendColor.dark( 140 );
 blCol.setAlphaF( 0.2 );
 QRect rect = cursorRect();
 rect.setX(0);
 rect.setWidth(viewport()->width());
-QPainter painter(viewport());
 if (!highlightLine)
   {
-  const QBrush brush(QColor("#ececec"));
+  const QBrush brush(colorLine);
   painter.fillRect(rect, brush);
-  painter.end();
+  //painter.end();
   }
 else
   {
   const QBrush brush(blCol);
   painter.fillRect(rect, brush);
-  painter.end();
-  }
-QPlainTextEdit::paintEvent(event);
+  //painter.end();
+  }      
+QTextDocument *doc = document();  
+QPointF offset(contentOffset());
+QTextBlock textCursorBlock = textCursor().block();
+bool hasMainSelection = textCursor().hasSelection();
+QRect er = event->rect();
+QRect viewportRect = viewport()->rect();
+painter.setBrushOrigin(offset);
+
+
+int blockSelectionIndex = -1;
+
+QAbstractTextDocumentLayout::PaintContext context = getPaintContext();
+if (inBlockSelectionMode
+    && context.selections.count() && context.selections.last().cursor == textCursor()) 
+{
+    blockSelectionIndex = context.selections.size()-1;
+    context.selections[blockSelectionIndex].format.clearBackground();
+}
+
+QTextLayout *cursor_layout = 0;
+QPointF cursor_offset;
+int cursor_cpos = 0;
+QPen cursor_pen;
+QTextBlock block = firstVisibleBlock();
+while (block.isValid()) {
+QRectF r = blockBoundingRect(block).translated(offset);
+
+if (r.bottom() >= er.top() && r.top() <= er.bottom()) {
+
+    QTextLayout *layout = block.layout();
+
+    QTextOption option = layout->textOption();
+
+	option.setFlags(option.flags() & ~QTextOption::SuppressColors);
+	painter.setPen(context.palette.text().color());
+   
+    layout->setTextOption(option);
+    layout->setFont(doc->defaultFont()); 
+int blpos = block.position();
+int bllen = block.length();
+
+QVector<QTextLayout::FormatRange> selections;
+QVector<QTextLayout::FormatRange> prioritySelections;
+
+for (int i = 0; i < context.selections.size(); ++i) {
+    const QAbstractTextDocumentLayout::Selection &range = context.selections.at(i);
+    const int selStart = range.cursor.selectionStart() - blpos;
+    const int selEnd = range.cursor.selectionEnd() - blpos;
+    if (selStart < bllen && selEnd >= 0
+	&& selEnd >= selStart) {
+	QTextLayout::FormatRange o;
+	o.start = selStart;
+	o.length = selEnd - selStart;
+	o.format = range.format;
+	if (i == blockSelectionIndex) {
+	    QString text = block.text();
+	    o.start = blockSelection.positionAtColumn(text, blockSelection.firstVisualColumn,0);
+	    o.length = blockSelection.positionAtColumn(text, blockSelection.lastVisualColumn,0) - o.start;
+	}
+	if ((hasMainSelection && i == context.selections.size()-1)
+	    || (o.format.foreground().style() == Qt::NoBrush
+	    && o.format.underlineStyle() != QTextCharFormat::NoUnderline
+	    && o.format.background() == Qt::NoBrush))
+	    prioritySelections.append(o);
+	else
+	    selections.append(o);
+    }
+}
+ selections += prioritySelections;
+ 
+QRectF blockSelectionCursorRect;
+if (inBlockSelectionMode
+	&& block.position() >= blockSelection.firstBlock.block().position()
+	&& block.position() <= blockSelection.lastBlock.block().position()) {
+    QString text = block.text();
+    qreal spacew = QFontMetricsF(font()).width(QLatin1Char(' '));
+
+    int offset = 0;
+    int relativePos  =  blockSelection.positionAtColumn(text, blockSelection.firstVisualColumn, &offset);
+    QTextLine line = layout->lineForTextPosition(relativePos);
+    qreal x = line.cursorToX(relativePos) + offset * spacew;
+
+    int eoffset = 0;
+    int erelativePos  =  blockSelection.positionAtColumn(text, blockSelection.lastVisualColumn, &eoffset);
+    QTextLine eline = layout->lineForTextPosition(erelativePos);
+    qreal ex = eline.cursorToX(erelativePos) + eoffset * spacew;
+
+    QRectF rr = line.naturalTextRect();
+    rr.moveTop(rr.top() + r.top());
+    rr.setLeft(r.left() + x);
+    if (line.lineNumber() == eline.lineNumber())  {
+	rr.setRight(r.left() + ex);
+    }
+    painter.fillRect(rr, palette().highlight());
+    if ((blockSelection.anchor == TextBlockSelection::TopLeft
+	    && block == blockSelection.firstBlock.block())
+	    || (blockSelection.anchor == TextBlockSelection::BottomLeft
+		&& block == blockSelection.lastBlock.block())
+	    ) {
+	rr.setRight(rr.left()+2);
+	blockSelectionCursorRect = rr;
+    }
+    for (int i = line.lineNumber() + 1; i < eline.lineNumber(); ++i) {
+	rr = layout->lineAt(i).naturalTextRect();
+	rr.moveTop(rr.top() + r.top());
+	rr.setLeft(r.left() + x);
+	painter.fillRect(rr, palette().highlight());
+    }
+
+    rr = eline.naturalTextRect();
+    rr.moveTop(rr.top() + r.top());
+    rr.setRight(r.left() + ex);
+    if (line.lineNumber() != eline.lineNumber())
+	painter.fillRect(rr, palette().highlight());
+    if ((blockSelection.anchor == TextBlockSelection::TopRight
+	  && block == blockSelection.firstBlock.block())
+	    || (blockSelection.anchor == TextBlockSelection::BottomRight
+		&& block == blockSelection.lastBlock.block())) {
+	rr.setLeft(rr.right()-2);
+	blockSelectionCursorRect = rr;
+    }
+}
+            bool drawCursor = ((true) // we want the cursor in read-only mode
+                               && context.cursorPosition >= blpos
+                               && context.cursorPosition < blpos + bllen);
+
+            bool drawCursorAsBlock = drawCursor && overwriteMode() ;
+
+            if (drawCursorAsBlock) {
+                int relativePos = context.cursorPosition - blpos;
+                bool doSelection = true;
+                QTextLine line = layout->lineForTextPosition(relativePos);
+                qreal x = line.cursorToX(relativePos);
+                qreal w = 0;
+                if (relativePos < line.textLength() - line.textStart()) {
+                    w = line.cursorToX(relativePos + 1) - x;
+                    if (doc->characterAt(context.cursorPosition) == QLatin1Char('\t')) {
+                        doSelection = false;
+                        qreal space = QFontMetricsF(layout->font()).width(QLatin1Char(' '));
+                        if (w > space) {
+                            x += w-space;
+                            w = space;
+                        }
+                    }
+                } else
+                    w = QFontMetrics(layout->font()).width(QLatin1Char(' ')); // in sync with QTextLine::draw()
+
+                QRectF rr = line.rect();
+                rr.moveTop(rr.top() + r.top());
+                rr.moveLeft(r.left() + x);
+                rr.setWidth(w);
+                painter.fillRect(rr, palette().text());
+                if (doSelection) {
+                    QTextLayout::FormatRange o;
+                    o.start = relativePos;
+                    o.length = 1;
+                    o.format.setForeground(palette().base());
+                    selections.append(o);
+                }
+            }
+layout->draw(&painter, offset, selections, er); 
+            if ((drawCursor && !drawCursorAsBlock)
+                || (context.cursorPosition < -1
+                    && !layout->preeditAreaText().isEmpty())) {
+                int cpos = context.cursorPosition;
+                if (cpos < -1)
+                    cpos = layout->preeditAreaPosition() - (cpos + 2);
+                else
+                    cpos -= blpos;
+                cursor_layout = layout;
+                cursor_offset = offset;
+                cursor_cpos = cpos;
+                cursor_pen = painter.pen();
+            }
+#ifndef Q_WS_MAC // no visible cursor on mac
+            if (blockSelectionCursorRect.isValid())
+                painter.fillRect(blockSelectionCursorRect, palette().text());
+#endif
+}
+offset.ry() += r.height();
+
+
+if (offset.y() > viewportRect.height())
+    break;
+
+block = block.next();
+       if (!block.isVisible()) {
+            // invisible blocks do have zero line count
+            block = doc->findBlockByLineNumber(block.firstLineNumber());
+        }
+
+}
+    painter.setPen(context.palette.text().color());
+
+    if (backgroundVisible() && !block.isValid() && offset.y() <= er.bottom()
+        && (centerOnScroll() || verticalScrollBar()->maximum() == verticalScrollBar()->minimum())) {
+        painter.fillRect(QRect(QPoint((int)er.left(), (int)offset.y()), er.bottomRight()), palette().background());
+    }
+    
+
+   if (cursor_layout && !inBlockSelectionMode) {
+	cursor_pen.setBrush(QBrush(colorCursor));
+        painter.setPen(cursor_pen);
+        cursor_layout->drawCursor(&painter, cursor_offset, cursor_cpos, cursorWidth());
+    }
 }
 
 void LatexEditor::contextMenuEvent(QContextMenuEvent *e)
@@ -250,11 +520,12 @@ if (endBlock>=0)
   }
 menu->addSeparator();
 a=new QAction(tr("Jump to pdf"),menu);
-#ifdef Q_WS_MACX
-a->setShortcut(Qt::CTRL+Qt::Key_Dollar);
-#else
-a->setShortcut(Qt::CTRL+Qt::Key_Space);
-#endif
+a->setShortcut(vfocus);
+// #ifdef Q_WS_MACX
+// a->setShortcut(Qt::CTRL+Qt::Key_Dollar);
+// #else
+// a->setShortcut(Qt::CTRL+Qt::Key_Space);
+// #endif
 a->setData(QVariant(cursorForPosition(e->pos()).blockNumber() + 1));
 connect(a, SIGNAL(triggered()), this, SLOT(jumpToPdf()));
 menu->addAction(a);
@@ -790,7 +1061,7 @@ while (++end < text.length())
 
   if (IS_WORD_FORMING(ch))
   {
-    if ((first) && (ch=='}' || ch==']')) break;
+    if ((first) && (ch=='}' || ch==']')) {++end;break;}
     first=false;
     continue;
 	  
@@ -917,7 +1188,7 @@ if ( e->key()==Qt::Key_Tab)
 	if (txt.contains(QString(0x2022)))
 	    {
 	    //e->ignore();
-	    search(QString(0x2022) ,true,true,true,true);
+	    search(QString(0x2022) ,true,false,true,true);
 	    return;		
 	    }
 	}
@@ -928,7 +1199,7 @@ if ( e->key()==Qt::Key_Tab)
 	if (txtnext.contains(QString(0x2022)))
 	    {
 	    //e->ignore();
-	    search(QString(0x2022) ,true,true,true,true);
+	    search(QString(0x2022) ,true,false,true,true);
 	    return;		
 	    }
 	}
@@ -945,7 +1216,7 @@ else if ( e->key()==Qt::Key_Backtab)
 	if (txt.contains(QString(0x2022)))
 	    {
 	    //e->ignore();
-	    search(QString(0x2022) ,true,true,false,true);
+	    search(QString(0x2022) ,true,false,false,true);
 	    return;		
 	    }
 	}
@@ -996,18 +1267,37 @@ else if ((e->key()==Qt::Key_Enter)||(e->key()==Qt::Key_Return))
 		}
 	cursor.endEditBlock();
 	}
-#ifdef Q_WS_MACX
-else if (((e->modifiers() & ~Qt::ShiftModifier) == Qt::ControlModifier) && e->key()==Qt::Key_Dollar) 
-  {
-  emit requestpdf(textCursor().blockNumber() + 1);
-  }
-#else
-else if (((e->modifiers() & ~Qt::ShiftModifier) == Qt::ControlModifier) && e->key()==Qt::Key_Space) 
-  {
-  emit requestpdf(textCursor().blockNumber() + 1);
-  }
-#endif
-else QPlainTextEdit::keyPressEvent(e);
+else
+	{
+	int qtKeyCode = e->key();
+	if(e->modifiers() & Qt::ShiftModifier) {
+		qtKeyCode += Qt::SHIFT;
+	}
+	if(e->modifiers() & Qt::ControlModifier) {
+		qtKeyCode += Qt::CTRL;
+	}
+	if(e->modifiers() & Qt::AltModifier) {
+		qtKeyCode += Qt::ALT;
+	}
+	if(e->modifiers() & Qt::MetaModifier) {
+		qtKeyCode += Qt::META;
+	}
+	QKeySequence s1 = QKeySequence(qtKeyCode);
+	if (s1.matches(vfocus)==QKeySequence::ExactMatch) emit requestpdf(textCursor().blockNumber() + 1);
+
+// 	#ifdef Q_WS_MACX
+// 	else if (((e->modifiers() & ~Qt::ShiftModifier) == Qt::ControlModifier) && e->key()==Qt::Key_Dollar) 
+// 	  {
+// 	  emit requestpdf(textCursor().blockNumber() + 1);
+// 	  }
+// 	#else
+// 	else if (((e->modifiers() & ~Qt::ShiftModifier) == Qt::ControlModifier) && e->key()==Qt::Key_Space) 
+// 	  {
+// 	  emit requestpdf(textCursor().blockNumber() + 1);
+// 	  }
+// 	#endif
+	else QPlainTextEdit::keyPressEvent(e);
+	}
 if (c && !c->popup()->isVisible()) 
 	{
 	switch (e->key()) 
@@ -1083,18 +1373,29 @@ QObject::connect(c, SIGNAL(activated(const QString&)),this, SLOT(insertCompletio
 {
 if (c->widget() != this) return;
 QTextCursor tc = textCursor();
+//tc.select(QTextCursor::WordUnderCursor);
+//qDebug() << tc.selectedText();
 QStringList check=fullcommandUnderCursor();
 int t=check.at(1).toInt();
 int r=check.at(2).toInt();
 int w=check.at(0).size();
+//qDebug() << check << w;
+
+QString insert_word = completion;
+
 tc.movePosition(QTextCursor::PreviousCharacter,QTextCursor::KeepAnchor,t-r+1);
-tc.removeSelectedText();
-tc.movePosition(QTextCursor::NextCharacter,QTextCursor::KeepAnchor,w-t-1+r);
+QString bef=tc.selectedText();
 tc.removeSelectedText();
 int pos=tc.position();
-QString insert_word = completion;
+tc.movePosition(QTextCursor::NextCharacter,QTextCursor::KeepAnchor,w-t-1+r);
+QString aft=tc.selectedText();
+//qDebug() << bef << aft;
+//tc.removeSelectedText();
+if (bef.contains("{") || !aft.contains("}")) tc.removeSelectedText();
+else tc.setPosition(pos,QTextCursor::MoveAnchor);
+
 QString env;
-QRegExp rbb("begin\\{\\s*([A-Za-z_]+)\\}");
+QRegExp rbb("begin\\{\\s*([A-Za-z_]+(\\*)?)\\}");
 //QRegExp rbb("begin\\{\\s*(.*)\\}");
 if (completion.contains(rbb)) 
 	{
@@ -1110,7 +1411,7 @@ if (completion.contains(rbb))
 	    {
 	    tc.movePosition(QTextCursor::Up,QTextCursor::MoveAnchor,1);
 	    setTextCursor(tc);
-	    search(QString(0x2022) ,true,true,true,true);
+	    search(QString(0x2022) ,true,false,true,true);
 	    emit tooltiptab();
 	    }
 
@@ -1120,7 +1421,7 @@ else
 	tc.insertText(insert_word);
 	tc.setPosition(pos,QTextCursor::MoveAnchor);
 	setTextCursor(tc);
-	if (!search(QString(0x2022) ,true,true,true,true))
+	if (!search(QString(0x2022) ,true,false,true,true))
 	  {
 	  tc.setPosition(pos+completion.length(),QTextCursor::MoveAnchor);
 	  setTextCursor(tc);
@@ -1647,6 +1948,305 @@ void LatexEditor::requestNewNumLines(int n)
 emit numLinesChanged(n);
 }
 
+void LatexEditor::setKeyViewerFocus(QKeySequence s)
+{
+vfocus=s;
+}
+
+void LatexEditor::updateName(QString f)
+{
+QFileInfo fiold(fname);
+QFileInfo finew(f);
+if ((fname.startsWith("untitled") || (fiold.suffix()!="asy" && fiold.suffix()!="mp")) && (finew.suffix()=="asy" || finew.suffix()=="mp") )
+  {
+  highlighter->setModeGraphic(true);
+  highlighter->rehighlight();
+  }
+fname=f;
+}
+
+void LatexEditor::mouseMoveEvent(QMouseEvent *e)
+{
+QPlainTextEdit::mouseMoveEvent(e);
+
+if (e->modifiers() & Qt::AltModifier) 
+{
+    if (!inBlockSelectionMode) {
+	blockSelection.fromSelection(textCursor());
+	inBlockSelectionMode = true;
+    } else {
+
+	QTextCursor cursor = textCursor();
+	// get visual column
+	int column = blockSelection.columnAt(cursor.block().text(), cursor.positionInBlock());
+	if (cursor.positionInBlock() == cursor.block().length()-1) {
+	    column += (e->pos().x() - cursorRect().center().x())/QFontMetricsF(font()).width(QLatin1Char(' '));
+	}
+	  blockSelection.moveAnchor(cursor.blockNumber(), column);
+	setTextCursor(blockSelection.selection());
+	viewport()->update();
+    }
+}
+    if (viewport()->cursor().shape() == Qt::BlankCursor)
+        viewport()->setCursor(Qt::IBeamCursor);
+}
+
+void LatexEditor::mousePressEvent(QMouseEvent *e)
+{
+    if (e->button() == Qt::LeftButton) {
+    if (inBlockSelectionMode) {
+        inBlockSelectionMode = false;
+        blockSelection.clear();
+        QTextCursor cursor = textCursor();
+        cursor.clearSelection();
+        setTextCursor(cursor);
+    }       
+    }
+
+    QPlainTextEdit::mousePressEvent(e);
+}
+
+void LatexEditor::cut()
+{
+    if (inBlockSelectionMode) {
+        copy();
+        removeBlockSelection();
+        return;
+    }
+    QPlainTextEdit::cut();
+}
+
+void LatexEditor::paste()
+{
+    if (inBlockSelectionMode) {
+        removeBlockSelection();
+    }
+    QPlainTextEdit::paste();
+}
+
+void LatexEditor::removeBlockSelection(const QString &text)
+{
+    QTextCursor cursor = textCursor();
+    if (!cursor.hasSelection() || !inBlockSelectionMode)
+        return;
+
+    int cursorPosition = cursor.selectionStart();
+    cursor.clearSelection();
+    cursor.beginEditBlock();
+
+   
+    QTextBlock block = blockSelection.firstBlock.block();
+    QTextBlock lastBlock = blockSelection.lastBlock.block();
+    for (;;) {
+        QString text = block.text();
+        int startOffset = 0;
+        int startPos = blockSelection.positionAtColumn(text, blockSelection.firstVisualColumn, &startOffset);
+        int endOffset = 0;
+        int endPos = blockSelection.positionAtColumn(text, blockSelection.lastVisualColumn, &endOffset);
+
+        cursor.setPosition(block.position() + startPos);
+        cursor.setPosition(block.position() + endPos, QTextCursor::KeepAnchor);
+        cursor.removeSelectedText();
+
+        if (startOffset < 0)
+            cursor.insertText(QString(blockSelection.tabSize + startOffset, QLatin1Char(' ')));
+        if (endOffset < 0)
+            cursor.insertText(QString(-endOffset, QLatin1Char(' ')));
+
+        if (block == lastBlock)
+            break;
+        block = block.next();
+    }
+
+    cursor.setPosition(cursorPosition);
+    if (!text.isEmpty())
+        cursor.insertText(text);
+    cursor.endEditBlock();
+    setTextCursor(cursor);
+}
+
+QMimeData *LatexEditor::createMimeDataFromSelection() const
+{
+    if (inBlockSelectionMode) {
+        QMimeData *mimeData = new QMimeData;
+        QString text = copyBlockSelection();
+        mimeData->setData(QLatin1String("application/vnd.texmaker.vblocktext"), text.toUtf8());
+        mimeData->setText(text); // for exchangeability
+        return mimeData;
+    } else if (textCursor().hasSelection()) {
+        QTextCursor cursor = textCursor();
+        QMimeData *mimeData = new QMimeData;
+
+        // Copy the selected text as plain text
+        QString text = cursor.selectedText();
+        convertToPlainText(text);
+        mimeData->setText(text);
+
+        // Copy the selected text as HTML
+        {
+            // Create a new document from the selected text document fragment
+            QTextDocument *tempDocument = new QTextDocument;
+            QTextCursor tempCursor(tempDocument);
+            tempCursor.insertFragment(cursor.selection());
+
+            // Apply the additional formats set by the syntax highlighter
+            QTextBlock start = document()->findBlock(cursor.selectionStart());
+            QTextBlock end = document()->findBlock(cursor.selectionEnd());
+            end = end.next();
+
+            const int selectionStart = cursor.selectionStart();
+            const int endOfDocument = tempDocument->characterCount() - 1;
+            for (QTextBlock current = start; current.isValid() && current != end; current = current.next()) {
+                const QTextLayout *layout = current.layout();
+                foreach (const QTextLayout::FormatRange &range, layout->additionalFormats()) {
+                    const int start = current.position() + range.start - selectionStart;
+                    const int end = start + range.length;
+                    if (end <= 0 || start >= endOfDocument)
+                        continue;
+                    tempCursor.setPosition(qMax(start, 0));
+                    tempCursor.setPosition(qMin(end, endOfDocument), QTextCursor::KeepAnchor);
+                    tempCursor.setCharFormat(range.format);
+                }
+            }
+
+            // Reset the user states since they are not interesting
+            for (QTextBlock block = tempDocument->begin(); block.isValid(); block = block.next())
+                block.setUserState(-1);
+
+            // Make sure the text appears pre-formatted
+            tempCursor.setPosition(0);
+            tempCursor.movePosition(QTextCursor::End, QTextCursor::KeepAnchor);
+            QTextBlockFormat blockFormat = tempCursor.blockFormat();
+            blockFormat.setNonBreakableLines(true);
+            tempCursor.setBlockFormat(blockFormat);
+
+            mimeData->setHtml(tempCursor.selection().toHtml());
+            delete tempDocument;
+        }
+
+        /*
+          Try to figure out whether we are copying an entire block, and store the complete block
+          including indentation in the qtcreator.blocktext mimetype.
+        */
+        QTextCursor selstart = cursor;
+        selstart.setPosition(cursor.selectionStart());
+        QTextCursor selend = cursor;
+        selend.setPosition(cursor.selectionEnd());
+
+        bool startOk = blockSelection.cursorIsAtBeginningOfLine(selstart);
+        bool multipleBlocks = (selend.block() != selstart.block());
+
+        if (startOk && multipleBlocks) {
+            selstart.movePosition(QTextCursor::StartOfBlock);
+            if (blockSelection.cursorIsAtBeginningOfLine(selend))
+                selend.movePosition(QTextCursor::StartOfBlock);
+            cursor.setPosition(selstart.position());
+            cursor.setPosition(selend.position(), QTextCursor::KeepAnchor);
+            text = cursor.selectedText();
+            mimeData->setData(QLatin1String("application/vnd.texmaker.blocktext"), text.toUtf8());
+        }
+        return mimeData;
+    }
+    return 0;
+}
+
+bool LatexEditor::canInsertFromMimeData(const QMimeData *source) const
+{
+    return QPlainTextEdit::canInsertFromMimeData(source);
+}
+
+void LatexEditor::insertFromMimeData(const QMimeData *source)
+{
+    if (isReadOnly())
+        return;
+
+    if (source->hasFormat(QLatin1String("application/vnd.texmaker.vblocktext"))) {
+        QString text = QString::fromUtf8(source->data(QLatin1String("application/vnd.texmaker.vblocktext")));
+        if (text.isEmpty())
+            return;
+
+
+        QStringList lines = text.split(QLatin1Char('\n'));
+        QTextCursor cursor = textCursor();
+        cursor.beginEditBlock();
+        int initialCursorPosition = cursor.position();
+        int column = blockSelection.columnAt(cursor.block().text(), cursor.positionInBlock());
+        cursor.insertText(lines.first());
+        for (int i = 1; i < lines.count(); ++i) {
+            QTextBlock next = cursor.block().next();
+            if (next.isValid()) {
+                cursor.setPosition(next.position());
+            } else {
+                cursor.movePosition(QTextCursor::EndOfBlock);
+                cursor.insertBlock();
+            }
+            int offset = 0;
+            int position = blockSelection.positionAtColumn(cursor.block().text(), column, &offset);
+            cursor.setPosition(cursor.block().position() + position);
+            if (offset < 0) {
+                cursor.deleteChar();
+                cursor.insertText(QString(-offset, QLatin1Char(' ')));
+            } else {
+                cursor.insertText(QString(offset, QLatin1Char(' ')));
+            }
+            cursor.insertText(lines.at(i));
+        }
+        cursor.setPosition(initialCursorPosition);
+        cursor.endEditBlock();
+        setTextCursor(cursor);
+        ensureCursorVisible();
+
+
+        return;
+    }
+
+    QString text = source->text();
+    if (text.isEmpty())
+        return;
+
+    QTextCursor cursor = textCursor();
+        cursor.beginEditBlock();
+        cursor.insertText(text);
+        cursor.endEditBlock();
+        setTextCursor(cursor);
+}
+
+QString LatexEditor::copyBlockSelection() const
+{
+    QString selection;
+    QTextCursor cursor = textCursor();
+    if (!inBlockSelectionMode)
+        return selection;
+    QTextBlock block = blockSelection.firstBlock.block();
+    QTextBlock lastBlock = blockSelection.lastBlock.block();
+    for (;;) {
+        QString text = block.text();
+        int startOffset = 0;
+        int startPos = blockSelection.positionAtColumn(text, blockSelection.firstVisualColumn, &startOffset);
+        int endOffset = 0;
+        int endPos = blockSelection.positionAtColumn(text, blockSelection.lastVisualColumn, &endOffset);
+
+        if (startPos == endPos) {
+            selection += QString(endOffset - startOffset, QLatin1Char(' '));
+        } else {
+            if (startOffset < 0)
+                selection += QString(-startOffset, QLatin1Char(' '));
+            if (endOffset < 0)
+                --endPos;
+            selection += text.mid(startPos, endPos - startPos);
+            if (endOffset < 0) {
+                selection += QString(blockSelection.tabSize + endOffset, QLatin1Char(' '));
+            } else if (endOffset > 0) {
+                selection += QString(endOffset, QLatin1Char(' '));
+            }
+        }
+        if (block == lastBlock)
+            break;
+        selection += QLatin1Char('\n');
+        block = block.next();
+    }
+    return selection;
+}
 /*const QRectF LatexEditor::blockGeometry(const QTextBlock & block) 
 {
 qDebug() << "ok1" << block.isValid() << block.isVisible();
